/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "common.h"
#include "log.h"
#include "utils.h"

#ifdef  LOG_TAG
#undef  LOG_TAG
#endif
#define LOG_TAG "NETCORE_INSTALLER_PLUGIN"

#include <cstring>
#include <vector>
#include <sstream>
#include <glib.h>

typedef struct Metadata {
	const char *key;
	const char *value;
} Metadata;

const std::string valueType = "true";
const std::string mdKey = "http://tizen.org/metadata/prefer_dotnet_aot";
extern "C" int PKGMGR_MDPARSER_PLUGIN_INSTALL(const char *pkgId, const char *appId, GList *list)
{
	GList *tag = NULL;
	bool mdValue = false;
	Metadata *mdInfo = NULL;
	tag = g_list_first(list);
	while (tag) {
		mdInfo = (Metadata*)tag->data;
		if (mdInfo->key == mdKey && mdInfo->value == valueType) {
			_DBG("Prefer dotnet application AOT set TRUE");
			mdValue = true;
		}
		tag = g_list_next(tag);
	}

	if (mdValue) {
		if (createNiUnderPkgRoot(pkgId) != 0) {
			_ERR("Failed to get root path from [%s]", pkgId);
			return -1;
		} else {
			_DBG("Complete make application to native image");
		}
	}
	return 0;
}

extern "C" int PKGMGR_MDPARSER_PLUGIN_UPGRADE(const char *pkgId, const char *appId, GList *list)
{
	return PKGMGR_MDPARSER_PLUGIN_INSTALL(pkgId, appId, list);
}
